UfWord

Struct UfWord 

#[repr(transparent)]
pub struct UfWord(u16);
16-bit unsigned quantity in font design units.

Tuple Fields

0: u16

Implementations

Source

impl UfWord

pub const fn new(raw: u16) -> Self

pub const fn to_u16(self) -> u16

pub const fn to_fixed(self) -> Fixed

Converts this number to a 16.16 fixed point value.

pub fn apply_delta(self, delta: F48Dot16) -> f32

Applies an item variation delta, returning the varied value as a single precision floating point number.

A delta for a font unit valued target is already in font units, so the accumulated 48.16 delta applies unscaled. The result is intentionally not rounded back to an integer.

pub const fn to_be_bytes(self) -> [u8; 2]

The representation of this number as a big-endian byte array.